"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const constants_1 = require("../../constants");
const utils_1 = require("../../utils");
const getSummaryVariables = ({ summary, matchedOptions = [] }) => {
    if (summary === null) {
        return {
            summaryFirstPart: 'Based on your answers ',
            summaryLastPart: ' we recommend these matches.',
            itemsSeparator: ', ',
            lastSeparator: ' and ',
            isActiveSummary: true,
        };
    }
    const { text = '', is_active: isActive, items_separator: itemsSeparator, last_separator: lastSeparator, } = summary;
    const isActiveSummary = !!isActive && !!matchedOptions.length && !!(text === null || text === void 0 ? void 0 : text.length);
    const [summaryFirstPart, summaryLastPart] = (text === null || text === void 0 ? void 0 : text.split(constants_1.MATCHED_OPTIONS_PLACEHOLDER)) || [];
    return {
        summaryFirstPart,
        summaryLastPart,
        itemsSeparator,
        lastSeparator,
        isActiveSummary,
    };
};
function QuizResultsSummary({ summary, matchedOptions = [], }) {
    const { summaryFirstPart, summaryLastPart, itemsSeparator, lastSeparator, isActiveSummary } = getSummaryVariables({ summary, matchedOptions });
    const matchedOptionsTemplate = (0, utils_1.formatMatchedOptions)(matchedOptions, itemsSeparator, lastSeparator);
    if (!isActiveSummary)
        return null;
    return (react_1.default.createElement("p", { className: 'cio-results-explanation' },
        !!(summaryFirstPart === null || summaryFirstPart === void 0 ? void 0 : summaryFirstPart.length) && summaryFirstPart,
        !!matchedOptionsTemplate.length && react_1.default.createElement("span", null, matchedOptionsTemplate),
        !!(summaryLastPart === null || summaryLastPart === void 0 ? void 0 : summaryLastPart.length) && summaryLastPart));
}
exports.default = QuizResultsSummary;
