"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const useCioClient_1 = tslib_1.__importDefault(require("./useCioClient"));
const useConsoleErrors_1 = tslib_1.__importDefault(require("./useConsoleErrors"));
const usePropsGetters_1 = tslib_1.__importDefault(require("./usePropsGetters"));
const usePrimaryColorStyles_1 = tslib_1.__importDefault(require("./usePrimaryColorStyles"));
const useQuizEvents_1 = tslib_1.__importDefault(require("./useQuizEvents"));
const useQuizState_1 = tslib_1.__importDefault(require("./useQuizState"));
const useQuiz = (quizOptions) => {
    var _a;
    const { apiKey, cioJsClient, primaryColor, resultsPageOptions } = quizOptions;
    // Log console errors for required parameters quizId
    (0, useConsoleErrors_1.default)(quizOptions);
    // Quiz Cio Client
    const cioClient = (0, useCioClient_1.default)({ apiKey, cioJsClient });
    // Quiz state (Local and API)
    const quizState = (0, useQuizState_1.default)(quizOptions, cioClient);
    // Quiz callback events
    const quizEvents = (0, useQuizEvents_1.default)(quizOptions, cioClient, quizState);
    // Props getters
    const { quizApiState, quizLocalState, quizSessionStorageState } = quizState;
    const { skipToResults } = quizSessionStorageState;
    const propGetters = (0, usePropsGetters_1.default)(quizEvents, quizApiState, quizLocalState, resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.favoriteItems);
    const primaryColorStyles = (0, usePrimaryColorStyles_1.default)(primaryColor);
    (0, react_1.useEffect)(() => {
        if (skipToResults)
            quizEvents.hydrateQuiz();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    return Object.assign(Object.assign({ cioClient, state: {
            answers: {
                inputs: quizLocalState.answerInputs,
            },
            quiz: {
                requestState: quizApiState.quizRequestState,
                versionId: quizLocalState.quizVersionId,
                sessionId: quizLocalState.quizSessionId,
                currentQuestion: quizApiState.quizCurrentQuestion,
                results: quizApiState.quizResults,
                selectedOptionsWithAttributes: quizApiState.selectedOptionsWithAttributes,
                matchedOptions: quizApiState.matchedOptions,
                resultsConfig: (_a = quizApiState.resultsConfig) !== null && _a !== void 0 ? _a : null,
            },
            quizSessionStorageState,
        }, events: Object.assign({}, quizEvents) }, propGetters), { primaryColorStyles });
};
exports.default = useQuiz;
